using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Documents.RichText;
using Infragistics.Documents.RichText.Rtf;
using Infragistics.Documents.RichText.Word;
using System.Diagnostics;
using Microsoft.Win32;

namespace RTE_Load_Save
{
    /// <summary>
    /// Interaction logic for SharedUserControl.xaml
    /// </summary>
    public partial class SharedUserControl : UserControl
    {

        private string outputFile;

        public SharedUserControl()
        {
            InitializeComponent();
            RTE.ClipboardSerializationProviders.Add(RtfSerializationProvider.Instance);
            RTE.ClipboardSerializationProviders.Add(WordSerializationProvider.Instance);
            RTE.ClipboardFormats = "Rich Text Format";

            using (MemoryStream ms = new MemoryStream())
            {
                using (StreamWriter sr = new StreamWriter(ms))
                {
                    string text = "Test data format.";
                    sr.WriteLine(text);
                    sr.Flush();

                    RichTextDocument rtd = new RichTextDocument();

                    // Set the position to the beginning of the stream.
                    ms.Seek(0, SeekOrigin.Begin);

                    RTE.Document.LoadFromPlainText(ms);

                    //Saving to MemoryStream
                    using (MemoryStream msNew = new MemoryStream())
                    {
                        RTE.Document.SaveToPlainText(msNew);
                    }
                }
            }
        }

        private void BtnSave_Click(object sender, RoutedEventArgs e)
        {
            Save();
        }

        private void BtnLoad_Click(object sender, RoutedEventArgs e)
        {

            Load();
        }

        private void btnClearClipboard_Click(object sender, RoutedEventArgs e)
        {
#if SILVERLIGHT
            Clipboard.SetText(string.Empty);
#else
            Clipboard.Clear();
#endif

        }

        private void Save()
        {
            SaveFileDialog saveFileDialog = new SaveFileDialog();

            saveFileDialog.Filter = "docx Files|*.docx|Text documents|*.txt|Rich Text Format|*.rtf|HTML Files|*.html";
            saveFileDialog.FilterIndex = 1;

            bool? userClickedOK = saveFileDialog.ShowDialog();

            if (userClickedOK == true)
            {
                if (userClickedOK == true)
                {
                    System.IO.Stream fileStream = saveFileDialog.OpenFile();

                    if (saveFileDialog.SafeFileName.EndsWith(".docx"))
                    {
                        RTE.Document.SaveToWord(fileStream);
                    }
                    else if (saveFileDialog.SafeFileName.EndsWith(".rtf"))
                    {
                        RTE.Document.SaveToRtf(fileStream);
                    }
                    else if (saveFileDialog.SafeFileName.EndsWith(".txt"))
                    {
                        RTE.Document.SaveToPlainText(fileStream);
                    }
                    else if (saveFileDialog.SafeFileName.EndsWith(".html"))
                    {
                        RTE.Document.SaveToHtml(fileStream);
                    }
                    fileStream.Close();
                }
            }
        }

        private void Load()
        {
            OpenFileDialog OpenFileDialog = new OpenFileDialog();

            OpenFileDialog.Filter = "docx Files|*.docx|Text documents|*.txt|Rich Text Format|*.rtf|HTML Files|*.html";
            OpenFileDialog.FilterIndex = 1;

            bool? userClickedOK = OpenFileDialog.ShowDialog();

#if SILVERLIGHT

            if (userClickedOK == true)
            {
                var fi = OpenFileDialog.File;
                var fileStream = fi.OpenRead();

                if (fi.Name.EndsWith(".docx"))
                {
                    RTE.Document.LoadFromWord(fileStream);
                }
                else if (fi.Name.EndsWith(".rtf"))
                {
                    RTE.Document.LoadFromRtf(fileStream);
                }
                else if (fi.Name.EndsWith(".txt"))
                {
                    RTE.Document.LoadFromPlainText(fileStream);
                }
                else if (fi.Name.EndsWith(".html"))
                {
                    RTE.Document.LoadFromHtml(fileStream);
                }

                fileStream.Close();
            }
#else
            if (userClickedOK == true)
            {
                FileStream file = new FileStream(OpenFileDialog.FileName, FileMode.Open);
                if (OpenFileDialog.SafeFileName.EndsWith(".docx"))
                {
                    RTE.Document.LoadFromWord(file);
                }
                else if (OpenFileDialog.SafeFileName.EndsWith(".rtf"))
                {
                    RTE.Document.LoadFromRtf(file);
                }
                else if (OpenFileDialog.SafeFileName.EndsWith(".txt"))
                {
                    RTE.Document.LoadFromPlainText(file);
                }
                else if (OpenFileDialog.SafeFileName.EndsWith(".html"))
                {
                    RTE.Document.LoadFromHtml(file);
                }
                file.Close();
            }
#endif
        }
    }
}
